Accepting request 43599 from home:dimstar:branches:GNOME:Factory

Copy from home:dimstar:branches:GNOME:Factory/gtk2 via accept of submit request 43599 revision 5.
Request was accepted with message:
thanks, I'll clean it up

OBS-URL: https://build.opensuse.org/request/show/43599
OBS-URL: https://build.opensuse.org/package/show/GNOME:Factory/gtk2?expand=0&rev=108
This commit is contained in:
Vincent Untz 2010-07-21 11:40:05 +00:00 committed by Git OBS Bridge
parent 4ee7dbfa43
commit f1006c2428
7 changed files with 100 additions and 162 deletions

View File

@ -1,15 +0,0 @@
--- gtk+-2.10.1/gdk-pixbuf/queryloaders.c
+++ gtk+-2.10.1/gdk-pixbuf/queryloaders.c
@@ -263,6 +263,12 @@
g_printf ("# GdkPixbuf Image Loader Modules file\n"
"# Automatically generated file, do not edit\n"
"# Created by %s from gtk+-%s\n"
+ "#\n"
+ "# If you need to regenerate the Module Loader\n"
+ "# file, either run\n"
+ "# gdk-pixbuf-query-loaders > /etc/gtk-2.0/gdk-pixbuf.loaders\n"
+ "# or \n"
+ "# touch /var/adm/SuSEconfig/run-gtk ; SuSEconfig\n"
"#\n",
(prgname ? prgname : "gdk-pixbuf-query-loaders"),
GDK_PIXBUF_VERSION);

43
gtk+-2.20.1-pngmess.patch Normal file
View File

@ -0,0 +1,43 @@
--- gdk-pixbuf/io-png.c
+++ gdk-pixbuf/io-png.c
@@ -261,7 +261,7 @@ gdk_pixbuf__png_image_load (FILE *f, GError **error)
gchar *icc_profile_base64;
const gchar *icc_profile_title;
const gchar *icc_profile;
- gulong icc_profile_size;
+ png_uint_32 icc_profile_size;
guint32 retval;
gint compression_type;
@@ -344,7 +344,7 @@ gdk_pixbuf__png_image_load (FILE *f, GError **error)
(png_charpp) &icc_profile_title, &compression_type,
(png_charpp) &icc_profile, (png_uint_32*) &icc_profile_size);
if (retval != 0) {
- icc_profile_base64 = g_base64_encode ((const guchar *) icc_profile, icc_profile_size);
+ icc_profile_base64 = g_base64_encode ((const guchar *) icc_profile, (gsize)icc_profile_size);
gdk_pixbuf_set_option (pixbuf, "icc-profile", icc_profile_base64);
g_free (icc_profile_base64);
}
@@ -607,7 +607,7 @@ png_info_callback (png_structp png_read_ptr,
gchar *icc_profile_base64;
const gchar *icc_profile_title;
const gchar *icc_profile;
- gulong icc_profile_size;
+ png_uint_32 icc_profile_size;
guint32 retval;
gint compression_type;
@@ -679,9 +679,9 @@ png_info_callback (png_structp png_read_ptr,
/* Extract embedded ICC profile */
retval = png_get_iCCP (png_read_ptr, png_info_ptr,
(png_charpp) &icc_profile_title, &compression_type,
- (png_charpp) &icc_profile, (png_uint_32*) &icc_profile_size);
+ (png_charpp) &icc_profile, &icc_profile_size);
if (retval != 0) {
- icc_profile_base64 = g_base64_encode ((const guchar *) icc_profile, icc_profile_size);
+ icc_profile_base64 = g_base64_encode ((const guchar *) icc_profile, (gsize)icc_profile_size);
gdk_pixbuf_set_option (lc->pixbuf, "icc-profile", icc_profile_base64);
g_free (icc_profile_base64);
}
--
cgit v0.8.3.1

View File

@ -1,3 +0,0 @@
version https://git-lfs.github.com/spec/v1
oid sha256:0e081731d21e34ff45c82199490c2889504fa8b3c7e117c043e82ababaec0f65
size 19089076

3
gtk+-2.21.4.tar.bz2 Normal file
View File

@ -0,0 +1,3 @@
version https://git-lfs.github.com/spec/v1
oid sha256:7f70c73a97938a7014f4e83be01224a36dca0adcb53333dc4a7bb20f0e7855a5
size 18058932

View File

@ -1,3 +1,33 @@
-------------------------------------------------------------------
Tue Jul 6 10:20:52 CEST 2010 - dimstar@opensuse.org
- Update to version 2.21.4:
+ Revert a change in GtkCalendar that broke the pygtk build
+ Fix the building of input methods as modules.
+ Include gdk-pixbuf-2.0 in the .pc file requires
- Changes from version 2.21.3:
+ gdk-pixbuf has been moved into a separate module
+ gtk_init warns if it detects GTK2.x and GTK3 being used in the
same process
- Changes from version 2.21.2:
+ The newly added gdk_drag_context_get_action function has been
renamed to gdk_drag_context_get_selected_action to make the
name less confusing.
+ Introspection annotations have been added in many places
+ New accessors for sealed struct members:
- gtk_viewport_get_view_window
- gdk_drag_context_get_source_window
- Changes from version 2.21.1:
+ GDK has been sealed, with the addition of suitable accessors
-------------------------------------------------------------------
Thu May 20 12:49:46 CEST 2010 - fridrich.strba@bluewin.ch
- Fix a memory allocation problem in png loader
+ patch gtk+-2.20.1-pngmess.patch: backport upstream commit
f0cfc970ed917adb10d4f92ba9e8d3aa079449e0
-------------------------------------------------------------------
Mon May 3 22:16:19 CEST 2010 - captain.magnus@opensuse.org

View File

@ -1,5 +1,5 @@
#
# spec file for package gtk2 (Version 2.20.1)
# spec file for package gtk2 (Version 2.21.4)
#
# Copyright (c) 2010 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
@ -19,7 +19,7 @@
Name: gtk2
%define _name gtk+
Version: 2.20.1
Version: 2.21.4
Release: 1
# FIXME: 2.19.3 doesn't compile with parallel build. Check if this is still true for later versions.
# FIXME: when updating to next version, check whether we can remove the workaround for bgo#596977 below (removing -fomit-frame-pointer)
@ -32,12 +32,8 @@ Source1: SuSEconfig.gtk2
Source2: README.SuSE
Source3: gtkrc
Source4: baselibs.conf
# PATCH-FIX-UPSTREAM gtk2-potfiles.patch bgo599774 sbrabec@suse.cz - Fix POTFILES.in referring to missing file.
Patch1: gtk2-potfiles.patch
# PATCH-FIX-OPENSUSE gtk64.patch sbrabec@novell.com - 64-bit dual install. See also the Fedora patch for a simpler way of doing this.
Patch8: gtk64.patch
# PATCH-FIX-OPENSUSE gdk-modules-information.diff hhetter@suse.de - Info on how to manually regenerate modules information
Patch12: gdk-modules-information.diff
# PATCH-FEATURE-UPSTREAM bugzilla-129753-gtk+-2.8.9-localize-font-style-name.diff bnc129753 bgo319484 mfabian@novell.com - Translate the font styles in the GUI
Patch22: bugzilla-129753-gtk+-2.8.9-localize-font-style-name.diff
# PATCH-FIX-OPENSUSE bugzilla-131498-allow-xim-for-all-languages.patch bnc131498 mfabian@novell.com - Allow all languages to be run with the X Input Method
@ -57,6 +53,7 @@ BuildRequires: gcc-c++
BuildRequires: atk-devel
BuildRequires: cairo-devel
BuildRequires: cups-devel
BuildRequires: gdk-pixbuf-devel
# Needed for patches touching the build system
BuildRequires: gnome-common
BuildRequires: gnome-patch-translation
@ -152,7 +149,6 @@ configurable.
%lang_package
%prep
%setup -q -n %{_name}-%{version}
%patch1
translation-update-upstream
translation-update-upstream po-properties gtk20-properties
gnome-patch-translation-prepare
@ -162,7 +158,6 @@ cp -a %{S:2} .
# WARNING: This patch does not patch not installed demos and tests.
%patch8 -p1
%endif
%patch12 -p1
%patch22 -p1
%patch23 -p1
%patch24 -p1
@ -180,16 +175,18 @@ export CFLAGS="$CFLAGS -mminimal-toc"
export CFLAGS=`echo $CFLAGS | sed -e 's/-fomit-frame-pointer//g'`
%configure \
--enable-man \
--with-xinput=xfree
--with-xinput=xfree \
--disable-static
#make %{?jobs:-j%jobs}
make
%install
%makeinstall
find %{buildroot}%{_libdir} -name '*.la' -delete -print
mkdir -p $RPM_BUILD_ROOT/sbin/conf.d
mkdir -p $RPM_BUILD_ROOT%{_sysconfdir}/gtk-2.0
install -m 755 SuSEconfig.gtk2 $RPM_BUILD_ROOT/sbin/conf.d
touch $RPM_BUILD_ROOT%{_sysconfdir}/gtk-2.0/gtk.immodules $RPM_BUILD_ROOT%{_sysconfdir}/gtk-2.0/gdk-pixbuf.loaders
touch $RPM_BUILD_ROOT%{_sysconfdir}/gtk-2.0/gtk.immodules
install -m 644 %{SOURCE3} $RPM_BUILD_ROOT%{_sysconfdir}/gtk-2.0
mkdir -p $RPM_BUILD_ROOT%{_localstatedir}/cache/gtk-2.0
touch $RPM_BUILD_ROOT%{_localstatedir}/cache/gtk-2.0/icon-theme.cache-list
@ -197,17 +194,11 @@ mkdir -p $RPM_BUILD_ROOT%{_libdir}/gtk-2.0/{,2.10.0/}{engines,filesystems,immodu
%find_lang gtk20
%find_lang gtk20-properties gtk20.lang
%if "%_lib" == "lib64"
mv $RPM_BUILD_ROOT%{_bindir}/gdk-pixbuf-query-loaders\
$RPM_BUILD_ROOT%{_bindir}/gdk-pixbuf-query-loaders-64
mv $RPM_BUILD_ROOT%{_bindir}/gtk-query-immodules-2.0\
$RPM_BUILD_ROOT%{_bindir}/gtk-query-immodules-2.0-64
mv $RPM_BUILD_ROOT%{_sysconfdir}/gtk-2.0/gtk.immodules\
$RPM_BUILD_ROOT%{_sysconfdir}/gtk-2.0/gtk64.immodules
mv $RPM_BUILD_ROOT%{_sysconfdir}/gtk-2.0/gdk-pixbuf.loaders\
$RPM_BUILD_ROOT%{_sysconfdir}/gtk-2.0/gdk-pixbuf64.loaders
%endif
rm $RPM_BUILD_ROOT%{_libdir}/gtk-2.0/2*/*/*.la
rm $RPM_BUILD_ROOT/%{_libdir}/gtk-2.0/modules/*.la
%fdupes $RPM_BUILD_ROOT
%clean
@ -252,10 +243,8 @@ fi
%ghost %{_localstatedir}/cache/gtk-2.0/icon-theme.cache-list
%if "%_lib" == "lib64"
%ghost %{_sysconfdir}/gtk-2.0/gtk64.immodules
%ghost %{_sysconfdir}/gtk-2.0/gdk-pixbuf64.loaders
%else
%ghost %{_sysconfdir}/gtk-2.0/gtk.immodules
%ghost %{_sysconfdir}/gtk-2.0/gdk-pixbuf.loaders
%endif
%{_sysconfdir}/gtk-2.0/im-multipress.conf
/sbin/conf.d/SuSEconfig.gtk2
@ -273,14 +262,12 @@ fi
%defattr(-,root,root)
%{_bindir}/gtk-builder-convert
%{_bindir}/*-demo
%{_bindir}/*-csource
%{_datadir}/gtk-2.0
%{_datadir}/aclocal/*.m4
%{_includedir}/gail-1.0
%{_includedir}/gtk-2.0
%{_includedir}/gtk-unix-print-2.0
%{_libdir}/lib*.so
%{_libdir}/lib*a
%{_libdir}/gtk-2.0/include
%{_libdir}/pkgconfig/*.pc
%doc %{_mandir}/man*/*

View File

@ -1,127 +1,20 @@
Index: gtk+-2.19.0/demos/Makefile.am
Index: gtk+-2.21.4/gtk/Makefile.am
===================================================================
--- gtk+-2.19.0.orig/demos/Makefile.am
+++ gtk+-2.19.0/demos/Makefile.am
@@ -38,8 +38,8 @@ if CROSS_COMPILING
pixbuf_csource=$(GDK_PIXBUF_CSOURCE)
pixbuf_csource_deps=
else
-pixbuf_csource=GDK_PIXBUF_MODULE_FILE=$(top_builddir)/gdk-pixbuf/gdk-pixbuf.loaders $(top_builddir)/gdk-pixbuf/gdk-pixbuf-csource
-pixbuf_csource_deps=$(top_builddir)/gdk-pixbuf/gdk-pixbuf-csource $(top_builddir)/gdk-pixbuf/gdk-pixbuf.loaders
+pixbuf_csource=GDK_PIXBUF_MODULE_FILE=$(top_builddir)/gdk-pixbuf/gdk-pixbuf64.loaders $(top_builddir)/gdk-pixbuf/gdk-pixbuf-csource
+pixbuf_csource_deps=$(top_builddir)/gdk-pixbuf/gdk-pixbuf-csource $(top_builddir)/gdk-pixbuf/gdk-pixbuf64.loaders
endif
--- gtk+-2.21.4.orig/gtk/Makefile.am
+++ gtk+-2.21.4/gtk/Makefile.am
@@ -974,7 +974,7 @@ distclean-local:
test-inline-pixbufs.h: $(pixbuf_csource_deps) apple-red.png gnome-foot.png
Index: gtk+-2.19.0/gdk-pixbuf/Makefile.am
===================================================================
--- gtk+-2.19.0.orig/gdk-pixbuf/Makefile.am
+++ gtk+-2.19.0/gdk-pixbuf/Makefile.am
@@ -612,7 +612,7 @@ MAINTAINERCLEANFILES = \
gdk-pixbuf-enum-types.c \
gdk-pixbuf-marshal.h \
gdk-pixbuf-marshal.c \
- gdk-pixbuf.loaders
+ gdk-pixbuf64.loaders
#
# gdk-pixbuf-enum-types.h
@@ -701,10 +701,10 @@ endif
install-data-hook: install-ms-lib install-def-file
@if $(RUN_QUERY_LOADER_TEST) ; then \
$(mkinstalldirs) $(DESTDIR)$(sysconfdir)/gtk-2.0 ; \
- $(top_builddir)/gdk-pixbuf/gdk-pixbuf-query-loaders > $(DESTDIR)$(sysconfdir)/gtk-2.0/gdk-pixbuf.loaders ; \
+ $(top_builddir)/gdk-pixbuf/gdk-pixbuf-query-loaders > $(DESTDIR)$(sysconfdir)/gtk-2.0/gdk-pixbuf64.loaders ; \
else \
echo "***" ; \
- echo "*** Warning: gdk-pixbuf.loaders not built" ; \
+ echo "*** Warning: gdk-pixbuf64.loaders not built" ; \
echo "***" ; \
echo "*** Generate this file manually on host" ; \
echo "*** system using gdk-pixbuf-query-loaders" ; \
@@ -712,27 +712,27 @@ install-data-hook: install-ms-lib instal
fi
uninstall-local: uninstall-ms-lib uninstall-def-file
- rm -f $(DESTDIR)$(sysconfdir)/gtk-2.0/gdk-pixbuf.loaders
+ rm -f $(DESTDIR)$(sysconfdir)/gtk-2.0/gdk-pixbuf64.loaders
if CROSS_COMPILING
else
-all-local: gdk-pixbuf.loaders
+all-local: gdk-pixbuf64.loaders
endif
if BUILD_DYNAMIC_MODULES
-gdk-pixbuf.loaders: $(loader_LTLIBRARIES) gdk-pixbuf-query-loaders$(EXEEXT)
+gdk-pixbuf64.loaders: $(loader_LTLIBRARIES) gdk-pixbuf-query-loaders$(EXEEXT)
LOADERS=`echo libpixbufloader-*.la` ; \
if test "x$$LOADERS" != 'xlibpixbufloader-*.la' ; then \
echo "Writing a gdk-pixbuf.loader file to use when running examples before installing gdk-pixbuf."; \
- $(top_builddir)/gdk-pixbuf/gdk-pixbuf-query-loaders $$LOADERS > ./gdk-pixbuf.loaders ;\
+ $(top_builddir)/gdk-pixbuf/gdk-pixbuf-query-loaders $$LOADERS > ./gdk-pixbuf64.loaders ;\
else \
echo "No dynamic modules found; will use only static modules for uninstalled example programs."; \
- touch gdk-pixbuf.loaders; \
+ touch gdk-pixbuf64.loaders; \
fi
else
-gdk-pixbuf.loaders:
+gdk-pixbuf64.loaders:
echo "No dynamic modules found; will use only static modules for uninstalled example programs."; \
- touch gdk-pixbuf.loaders;
+ touch gdk-pixbuf64.loaders;
endif
-include $(top_srcdir)/git.mk
Index: gtk+-2.19.0/gtk/Makefile.am
===================================================================
--- gtk+-2.19.0.orig/gtk/Makefile.am
+++ gtk+-2.19.0/gtk/Makefile.am
@@ -949,7 +949,7 @@ distclean-local:
DEPS = $(gtktargetlib) $(top_builddir)/gdk-pixbuf/libgdk_pixbuf-$(GTK_API_VERSION).la $(top_builddir)/gdk/$(gdktargetlib)
DEPS = $(gtktargetlib) $(top_builddir)/gdk/$(gdktargetlib)
-TEST_DEPS = $(DEPS) gtk.immodules
+TEST_DEPS = $(DEPS) gtk64.immodules
LDADDS = \
$(gtktargetlib) \
@@ -1311,7 +1311,7 @@ if CROSS_COMPILING
gtk_update_icon_cache_program = $(GTK_UPDATE_ICON_CACHE)
else
gtk_update_icon_cache_program = \
- GDK_PIXBUF_MODULE_FILE=$(top_builddir)/gdk-pixbuf/gdk-pixbuf.loaders \
+ GDK_PIXBUF_MODULE_FILE=$(top_builddir)/gdk-pixbuf/gdk-pixbuf64.loaders \
./gtk-update-icon-cache
endif
Index: gtk+-2.19.0/gtk/gtkmodules.c
Index: gtk+-2.21.4/gtk/gtkmodules.c
===================================================================
--- gtk+-2.19.0.orig/gtk/gtkmodules.c
+++ gtk+-2.19.0/gtk/gtkmodules.c
--- gtk+-2.21.4.orig/gtk/gtkmodules.c
+++ gtk+-2.21.4/gtk/gtkmodules.c
@@ -68,7 +68,7 @@ get_module_path (void)
if (home_dir)
home_gtk_dir = g_build_filename (home_dir, ".gtk-2.0", NULL);
@ -131,10 +24,10 @@ Index: gtk+-2.19.0/gtk/gtkmodules.c
exe_prefix = g_getenv ("GTK_EXE_PREFIX");
if (exe_prefix)
Index: gtk+-2.19.0/gtk/gtkrc.c
Index: gtk+-2.21.4/gtk/gtkrc.c
===================================================================
--- gtk+-2.19.0.orig/gtk/gtkrc.c
+++ gtk+-2.19.0/gtk/gtkrc.c
--- gtk+-2.21.4.orig/gtk/gtkrc.c
+++ gtk+-2.21.4/gtk/gtkrc.c
@@ -450,7 +450,7 @@ gtk_rc_get_im_module_file (void)
if (im_module_file)
result = g_strdup (im_module_file);
@ -144,11 +37,11 @@ Index: gtk+-2.19.0/gtk/gtkrc.c
}
return result;
Index: gtk+-2.19.0/modules/input/Makefile.am
Index: gtk+-2.21.4/modules/input/Makefile.am
===================================================================
--- gtk+-2.19.0.orig/modules/input/Makefile.am
+++ gtk+-2.19.0/modules/input/Makefile.am
@@ -191,11 +191,11 @@ install-data-hook:
--- gtk+-2.21.4.orig/modules/input/Makefile.am
+++ gtk+-2.21.4/modules/input/Makefile.am
@@ -189,11 +189,11 @@ install-data-hook:
@if $(RUN_QUERY_IMMODULES_TEST) ; then \
echo $(mkinstalldirs) $(DESTDIR)$(sysconfdir)/gtk-2.0 ; \
$(mkinstalldirs) $(DESTDIR)$(sysconfdir)/gtk-2.0 ; \
@ -163,7 +56,7 @@ Index: gtk+-2.19.0/modules/input/Makefile.am
echo "***" ; \
echo "*** Generate this file manually on host" ; \
echo "*** system using gtk-query-immodules-2.0" ; \
@@ -203,7 +203,7 @@ install-data-hook:
@@ -201,7 +201,7 @@ install-data-hook:
fi
uninstall-local:
@ -172,7 +65,7 @@ Index: gtk+-2.19.0/modules/input/Makefile.am
if BUILD_DYNAMIC_MODULES
@@ -239,14 +239,14 @@ noinst_LTLIBRARIES = \
@@ -237,14 +237,14 @@ noinst_LTLIBRARIES = \
included-modules: $(noinst_LTLIBRARIES)
Index: gtk+-2.19.0/gdk-pixbuf/gdk-pixbuf-io.c
===================================================================
--- gtk+-2.19.0.orig/gdk-pixbuf/gdk-pixbuf-io.c
+++ gtk+-2.19.0/gdk-pixbuf/gdk-pixbuf-io.c
@@ -286,7 +286,7 @@ correct_prefix (gchar **path)
/* This is an entry put there by gdk-pixbuf-query-loaders on the
* packager's system. On Windows a prebuilt GTK+ package can be
* installed in a random location. The gdk-pixbuf.loaders file
* distributed in such a package contains paths from the package
* builder's machine. Replace the build-time prefix with the
* installation prefix on this machine.
@@ -305,7 +305,7 @@ gdk_pixbuf_get_module_file (void)
gchar *result = g_strdup (g_getenv ("GDK_PIXBUF_MODULE_FILE"));
if (!result)
- result = g_build_filename (GTK_SYSCONFDIR, "gtk-2.0", "gdk-pixbuf.loaders", NULL);
+ result = g_build_filename (GTK_SYSCONFDIR, "gtk-2.0", "gdk-pixbuf64.loaders", NULL);
return result;
}
@@ -286,7 +286,7 @@ correct_prefix (gchar **path)
/* This is an entry put there by gdk-pixbuf-query-loaders on the
* packager's system. On Windows a prebuilt GTK+ package can be
- * installed in a random location. The gdk-pixbuf.loaders file
+ * installed in a random location. The gdk-pixbuf64.loaders file
* distributed in such a package contains paths from the package
* builder's machine. Replace the build-time prefix with the